summaryrefslogtreecommitdiffstats
path: root/c++/src/H5CommonFG.cpp
diff options
context:
space:
mode:
authorBinh-Minh Ribler <bmribler@hdfgroup.org>2004-08-07 05:46:10 (GMT)
committerBinh-Minh Ribler <bmribler@hdfgroup.org>2004-08-07 05:46:10 (GMT)
commit47dd278b15375b71ff8663ce51778f590f69541a (patch)
tree2e5813bf7f87e10726605d96be13f1606e693de9 /c++/src/H5CommonFG.cpp
parent4b3ebf1646df8a613d53dad96f82eb0bb68f0aa2 (diff)
downloadhdf5-47dd278b15375b71ff8663ce51778f590f69541a.zip
hdf5-47dd278b15375b71ff8663ce51778f590f69541a.tar.gz
hdf5-47dd278b15375b71ff8663ce51778f590f69541a.tar.bz2
[svn-r9046] Purpose:
Code cleanup Description: DataType::commit had incorrect parameter, H5Object. Changed it to CommonFG, for H5File and Group. The change caused additional header files needed for several other cpp files. Moved some functions from Group into the base class CommonFG for H5File too. Platforms tested: SunOS 5.7 (arabica) Linux 2.4 (eirene) Misc. update:
Diffstat (limited to 'c++/src/H5CommonFG.cpp')
-rw-r--r--c++/src/H5CommonFG.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/c++/src/H5CommonFG.cpp b/c++/src/H5CommonFG.cpp
index 246becb..e3e7616 100644
--- a/c++/src/H5CommonFG.cpp
+++ b/c++/src/H5CommonFG.cpp
@@ -514,7 +514,7 @@ void CommonFG::unmount( const string& name ) const
}
//--------------------------------------------------------------------------
-// Function: CommonFG::p_openDataType (private)
+// Function: CommonFG::p_open_data_type (private)
// Purpose Opens the named datatype and returns the datatype's identifier.
// Return Id of the datatype
// Exception H5::FileIException or H5::GroupIException
@@ -524,7 +524,7 @@ void CommonFG::unmount( const string& name ) const
// datatypes.
// Programmer Binh-Minh Ribler - 2000
//--------------------------------------------------------------------------
-hid_t CommonFG::p_openDataType( const char* name ) const
+hid_t CommonFG::p_open_data_type( const char* name ) const
{
// Call C function H5Topen to open the named datatype in this group,
// giving either the file or group id
@@ -542,7 +542,7 @@ hid_t CommonFG::p_openDataType( const char* name ) const
//
// The following member functions use the private function
// p_openDataType to open a named datatype in this location
//
//--------------------------------------------------------------------------
@@ -555,7 +555,7 @@ hid_t CommonFG::p_openDataType( const char* name ) const
//--------------------------------------------------------------------------
DataType CommonFG::openDataType( const char* name ) const
{
- DataType data_type( p_openDataType( name ));
+ DataType data_type( p_open_data_type( name ));
return( data_type );
}
@@ -581,7 +581,7 @@ DataType CommonFG::openDataType( const string& name ) const
//--------------------------------------------------------------------------
EnumType CommonFG::openEnumType( const char* name ) const
{
- EnumType enum_type( p_openDataType( name ));
+ EnumType enum_type( p_open_data_type( name ));
return( enum_type );
}
@@ -607,7 +607,7 @@ EnumType CommonFG::openEnumType( const string& name ) const
//--------------------------------------------------------------------------
CompType CommonFG::openCompType( const char* name ) const
{
- CompType comp_type( p_openDataType( name ));
+ CompType comp_type( p_open_data_type( name ));
return( comp_type );
}
@@ -633,7 +633,7 @@ CompType CommonFG::openCompType( const string& name ) const
//--------------------------------------------------------------------------
IntType CommonFG::openIntType( const char* name ) const
{
- IntType int_type( p_openDataType( name ));
+ IntType int_type( p_open_data_type( name ));
return( int_type );
}
@@ -659,7 +659,7 @@ IntType CommonFG::openIntType( const string& name ) const
//--------------------------------------------------------------------------
FloatType CommonFG::openFloatType( const char* name ) const
{
- FloatType float_type( p_openDataType( name ));
+ FloatType float_type( p_open_data_type( name ));
return( float_type );
}
@@ -685,7 +685,7 @@ FloatType CommonFG::openFloatType( const string& name ) const
//--------------------------------------------------------------------------
StrType CommonFG::openStrType( const char* name ) const
{
- StrType str_type( p_openDataType( name ));
+ StrType str_type( p_open_data_type( name ));
return( str_type );
}
@@ -542,7 +542,7 @@ hid_t CommonFG::p_openDataType( const char* name ) const
//
// The following member functions use the private function
-// p_openDataType to open a named datatype in this location
+// p_open_data_type to open a named datatype in this location
//
//--------------------------------------------------------------------------